@@ -24,6 +24,7 @@ pub enum FieldType {
 pub struct TextField {
     node: Node,
     pub label: Option<String>,
+    pub value: Option<String>,
     pub helper_text: Option<String>,
     pub placeholder: Option<String>,
     pub leading_icon: Option<String>,
@@ -46,6 +47,7 @@ impl TextField {
         TextField {
             node: Default::default(),
             label: None,
+            value: None,
             helper_text: None,
             placeholder: None,
             leading_icon: None,
@@ -61,6 +63,11 @@ impl TextField {
         self.clone()
     }
 
+    pub fn value(&mut self, value: &str) -> Self {
+        self.value = Some(value.to_string());
+        self.clone()
+    }
+
     pub fn helper_text(&mut self, helper_text: &str) -> Self {
         self.helper_text = Some(helper_text.to_string());
         self.clone()
@@ -100,6 +107,10 @@ impl Renderable for TextField {
             .set_attr("id", self.name.as_str())
             .set_attr("name", self.name.as_str());
 
+        if let Some(value) = field.value {
+            input.set_attr("value", &value);
+        }
+
         if let Some(placeholder) = field.placeholder {
             input.set_attr("placeholder", placeholder.as_str());
         }
